#ifndef __MY_MAIN_VIEW_H
#define __MY_MAIN_VIEW_H

#include <qwidget.h>
#include <qimage.h>
#include <kconfig.h>
#include "QwSpriteField.h"
#include "sprites.h"
#include "dialogs.h"

class MyMainView:public QWidget
{
   Q_OBJECT
public:
   MyMainView(QWidget *parent=0, const char *name=0);
   ~MyMainView();
   void readConfig(KConfig *cfg);
   
public slots:   
   void newRound();
   void newGame();
   void pause();
   void resume();
   void gameSetup();
   void keySetup();
signals:
   void hitPoints(int pn,int hp);
   void energy(int pn,int en);
   void wins(int pn,int w);
   void setStatusText(const char* str,int id);
   
protected:
   virtual void resizeEvent(QResizeEvent *event);
   virtual void timerEvent(QTimerEvent *event);
   virtual void keyPressEvent(QKeyEvent *event);
   virtual void keyReleaseEvent(QKeyEvent *event);
   SConfig modifyConfig(SConfig conf);
   void calculateGravity(MobileSprite *sp);
   void moveShips();
   void moveBullets();
   void moveMines();
   void moveExplosions();
   void collisions();
private:
   QwImageSpriteField field;
   QwSpriteFieldView view;
   
   SOptions options;
   SConfig customConfig,config;

   int timerID;
   bool playerKeyPressed[2][PlayerKeyNum];
   bool functionKeyPressed[FunctionKeyNum];
   bool bulletShot[2];
   bool minePut[2];
   bool waitForStart;
   float gameEnd;
   
// sprites
   QList<QImage> shipImages;
   QList<QPoint> points;
   QImage bulletImage;
   QwSpritePixmapSequence *bulletsequence[2];
   QwSpritePixmapSequence *shipsequence[2];
   QwSpritePixmapSequence *explosionsequence;
   QwSpritePixmapSequence *minesequence[2];
   QwSpritePixmapSequence *mineexplosionsequence;
   

   ShipSprite *ship[2];
   SunSprite *sun;
   QwTextSprite *textSprite;
   QList<BulletSprite> bullets[2];
   QList<MineSprite> mines[2];
   QList<ExplosionSprite> explosions;
// sin,cos
   double a_cos[ROTNUM];
   double a_sin[ROTNUM];
};



#endif
